Tutorial
********
This document provides a comprehensive introduction to the basics of the Pants
networking framework. It is intended to be a resource for developers new to
Pants and aims to provide enough information for you to immediately get started
writing code.

It covers the basic API only and does not go in to great detail about the
Pants internals, nor does it cover best practices, common techniques or other
advanced topics. It assumes a decent knowledge of Python 2 and a basic
knowledge of networking.

If you have any questions or comments regarding this material, please head to
the mailing list or the IRC channel and seek clarification.

.. toctree::
    :maxdepth: 2
    
    overview
    channels
    clients
    servers
    timers
    events
